
/**
 * Attaches the behavior.
 */
Drupal.behaviors.uploadify = function(context) {
  for (var id in Drupal.settings.uploadify) {
    if (!$('#'+ id + '.uploadify-processed').size()) {
      var elementSettings = Drupal.settings.uploadify[id];

      $('#' + id, context).each(function() {
        elementSettings.element = this;
        var uploadify = new Drupal.uploadify(id, elementSettings);
      });

      $('#' + id, context).addClass('uploadify-processed');
    }
  }
};

/**
 * Uploadify object.
 */
Drupal.uploadify = function(id, elementSettings) {
  elementSettings.queueID = id + '-queue';
  var element = elementSettings.element;
  var extraSettings = {};
  var replace = $('#' + elementSettings.uploadifyReplace);
  var classFilled = 'uploadify-file-queue-filled';

  $(elementSettings.element).uploadify({
    'uploader'       : elementSettings.uploader,
    'script'         : elementSettings.script,
    'fileDataName'   : elementSettings.fileDataName,
    'cancelImg'      : elementSettings.cancelImg,
    'hideButton'     : elementSettings.hideButton,
    'queueID'        : elementSettings.queueID,
    'auto'           : elementSettings.auto,
    // onSelectOnce changes post for 1st file in queue, others changed by onComplete.
    onSelectOnce: function(event, data) {
      if (data.fileCount > 0) {
        // Set new post.
        var fieldSettings = Drupal.settings['uploadify_' + elementSettings.scriptData.field_name];
        for (var widgetId in fieldSettings) {
          for (var elementId in fieldSettings[widgetId]) {
            var elementName = $('#' + elementId).attr('name');
            if (typeof(elementName) == 'string') {
              var elementValue = $('#' + elementId).val();
              extraSettings[elementName] = elementValue;
            }
          }
        }
        jQuery.extend(elementSettings.scriptData, extraSettings);
        $(element).uploadifySettings('scriptData', elementSettings.scriptData, true);
        // Add a class to filequeue div.
        $('#' + elementSettings.queueID).addClass(classFilled);
      }
    },
    onCancel: function(event, queueID, fileObj, data) {
      // Remove a class to filequeue div.
      if (data.fileCount <= 0) {
        $('#' + elementSettings.queueID).removeClass(classFilled);
      }
      return true;
    },
    onClearQueue: function(event, data) {
      // Remove a class to filequeue div.
      if (data.fileCount <= 0) {
        $('#' + elementSettings.queueID).removeClass(classFilled);
      }
      return true;
    },
    onOpen: function(event, queueID, fileObj) {
      // TODO: disable something.
    },
    onComplete: function(event, queueID, fileObj, response, data) {
      if (typeof(response) == 'string') {
        response = Drupal.parseJson(response);
      }
      var newContent = $(response.data);
      // Replace.
      // TODO
      $(replace).children('table').remove();
      $(replace).prepend(newContent);
      // Attach behaviors.
      if (newContent.parents('html').length > 0) {
        Drupal.attachBehaviors(newContent);
      }
      // Set new post.
      if (data.fileCount > 0) {
        var fieldSettings = Drupal.settings['uploadify_' + elementSettings.scriptData.field_name];
        for (var widgetId in fieldSettings) {
          for (var elementId in fieldSettings[widgetId]) {
            var elementName = $('#' + elementId).attr('name');
            if (typeof(elementName) == 'string') {
              var elementValue = $('#' + elementId).val();
              extraSettings[elementName] = elementValue;
            }
          }
        }
        jQuery.extend(elementSettings.scriptData, extraSettings);
        $(element).uploadifySettings('scriptData', elementSettings.scriptData, true);
      }
      // Remove a class to filequeue div.
      else {
        $('#' + elementSettings.queueID).removeClass(classFilled);
      }
      // Success.
      return true;
    },
    onError: function(event, queueID, fileObj, errorObj) {
      alert(errorObj.type);
      alert(errorObj.info);
    },
    'wmode'          : 'transparent',
    'multi'          : true
  });
};
